@@ -17,6 +17,7 @@
 #include <xmlsec/transforms.h>
 
 #include <windows.h>
+#include <wincrypt.h>
 
 #ifdef __cplusplus
 extern "C" {
@@ -49,6 +50,7 @@ XMLSEC_CRYPTO_EXPORT xmlSecKeyDataId    xmlSecMSCngKeyDataRawX509CertGetKlass(vo
         xmlSecMSCngX509StoreGetKlass()
 XMLSEC_CRYPTO_EXPORT xmlSecKeyDataStoreId xmlSecMSCngX509StoreGetKlass(void);
 
+XMLSEC_CRYPTO_EXPORT PCCERT_CONTEXT     xmlSecMSCngKeyDataX509GetKeyCert     (xmlSecKeyDataPtr data);
 XMLSEC_CRYPTO_EXPORT int                xmlSecMSCngKeyDataX509AdoptKeyCert   (xmlSecKeyDataPtr data,
                                                                               PCCERT_CONTEXT cert);
 XMLSEC_CRYPTO_EXPORT int                xmlSecMSCngKeyDataX509AdoptCert      (xmlSecKeyDataPtr data,
