@@ -404,7 +404,7 @@ xmlSecKeyReqMatchKey(xmlSecKeyReqPtr keyReq, xmlSecKeyPtr key) {
     xmlSecAssert2(xmlSecKeyIsValid(key), -1);
 
     if((keyReq->keyType != xmlSecKeyDataTypeUnknown) && ((xmlSecKeyGetType(key) & keyReq->keyType) == 0)) {
-         return(0);
+        return(0);
     }
     if((keyReq->keyUsage != xmlSecKeyDataUsageUnknown) && ((keyReq->keyUsage & key->usage) == 0)) {
         return(0);
@@ -430,13 +430,11 @@ xmlSecKeyReqMatchKeyValue(xmlSecKeyReqPtr keyReq, xmlSecKeyDataPtr value) {
 
     if((keyReq->keyId != xmlSecKeyDataIdUnknown) &&
        (!xmlSecKeyDataCheckId(value, keyReq->keyId))) {
-
         return(0);
     }
     if((keyReq->keyBitsSize > 0) &&
        (xmlSecKeyDataGetSize(value) > 0) &&
        (xmlSecKeyDataGetSize(value) < keyReq->keyBitsSize)) {
-
         return(0);
     }
     return(1);
@@ -605,6 +603,37 @@ xmlSecKeyCopy(xmlSecKeyPtr keyDst, xmlSecKeyPtr keySrc) {
     return(0);
 }
 
+#define XMLSEC_SWAP(val1, val2, TYPE)   \
+    {                                   \
+        TYPE _tmp = (val1);             \
+        (val1) = (val2);                \
+        (val2) = _tmp;                  \
+    }
+
+/**
+ * xmlSecKeySwap:
+ * @key1:             the first key.
+ * @key2:             the second key.
+ *
+ * Swaps key data for @key1 and@key2
+ *
+ * Returns: 0 on success or a negative value if an error occurs.
+ */
+int
+xmlSecKeySwap(xmlSecKeyPtr key1, xmlSecKeyPtr key2) {
+    xmlSecAssert2(key1 != NULL, -1);
+    xmlSecAssert2(key2 != NULL, -1);
+
+    XMLSEC_SWAP(key1->name,             key2->name,             xmlChar*);
+    XMLSEC_SWAP(key1->value,            key2->value,            xmlSecKeyDataPtr);
+    XMLSEC_SWAP(key1->dataList,         key2->dataList,         xmlSecPtrListPtr);
+    XMLSEC_SWAP(key1->usage,            key2->usage,            xmlSecKeyUsage);
+    XMLSEC_SWAP(key1->notValidBefore,   key2->notValidBefore,   time_t);
+    XMLSEC_SWAP(key1->notValidAfter,    key2->notValidAfter,    time_t);
+
+    return(0);
+}
+
 /**
  * xmlSecKeyDuplicate:
  * @key:                the pointer to the #xmlSecKey structure.
@@ -723,6 +752,39 @@ xmlSecKeySetName(xmlSecKeyPtr key, const xmlChar* name) {
     return(0);
 }
 
+/**
+ * xmlSecKeySetNameEx:
+ * @key:                the pointer to key.
+ * @name:               the new key name.
+ * @nameSize:           the size of @name.
+ *
+ * Sets key name (see also #xmlSecKeyGetName function).
+ *
+ * Returns: 0 on success or a negative value if an error occurs.
+ */
+int
+xmlSecKeySetNameEx(xmlSecKeyPtr key, const xmlChar* name, xmlSecSize nameSize) {
+    xmlSecAssert2(key != NULL, -1);
+
+    if(key->name != NULL) {
+        xmlFree(key->name);
+        key->name = NULL;
+    }
+
+    if((name != NULL) && (nameSize > 0)) {
+        int nameLen;
+
+        XMLSEC_SAFE_CAST_SIZE_TO_INT(nameSize, nameLen, return(-1), NULL);
+        key->name = xmlStrndup(name, nameLen);
+        if(key->name == NULL) {
+            xmlSecStrdupError(name, NULL);
+            return(-1);
+        }
+    }
+
+    return(0);
+}
+
 /**
  * xmlSecKeyGetValue:
  * @key:                the pointer to key.
@@ -760,6 +822,24 @@ xmlSecKeySetValue(xmlSecKeyPtr key, xmlSecKeyDataPtr value) {
     return(0);
 }
 
+/**
+ * xmlSecKeyGetSize:
+ * @key:                the pointer to key.
+ *
+ * Gets key size (in bits). Also see #xmlSecKeyDataGetSize function.
+ *
+ * Returns: key size (in bits).
+ */
+xmlSecSize
+xmlSecKeyGetSize(xmlSecKeyPtr key) {
+    xmlSecAssert2(key != NULL, 0);
+
+    if(key->value == NULL) {
+        return(0);
+    }
+    return(xmlSecKeyDataGetSize(key->value));
+}
+
 /**
  * xmlSecKeyGetData:
  * @key:                the pointer to key.
@@ -1208,10 +1288,10 @@ xmlSecKeyReadMemory(xmlSecKeyDataId dataId, const xmlSecByte* data, xmlSecSize d
 
 /**
  * xmlSecKeysMngrGetKey:
- * @keyInfoNode:        the pointer to <dsig:KeyInfo/> node.
- * @keyInfoCtx:         the pointer to <dsig:KeyInfo/> node processing context.
+ * @keyInfoNode:        the pointer to &lt;dsig:KeyInfo/&gt; node.
+ * @keyInfoCtx:         the pointer to &lt;dsig:KeyInfo/&gt; node processing context.
  *
- * Reads the <dsig:KeyInfo/> node @keyInfoNode and extracts the key.
+ * Reads the &lt;dsig:KeyInfo/&gt; node @keyInfoNode and extracts the key.
  *
  * Returns: the pointer to key or NULL if the key is not found or
  * an error occurs.
@@ -1223,8 +1303,7 @@ xmlSecKeysMngrGetKey(xmlNodePtr keyInfoNode, xmlSecKeyInfoCtxPtr keyInfoCtx) {
 
     xmlSecAssert2(keyInfoCtx != NULL, NULL);
 
-
-    /* first try to read data from <dsig:KeyInfo/> node */
+    /* first try to read data from &lt;dsig:KeyInfo/&gt; node */
     key = xmlSecKeyCreate();
     if(key == NULL) {
         xmlSecInternalError("xmlSecKeyCreate", NULL);
@@ -1249,8 +1328,8 @@ xmlSecKeysMngrGetKey(xmlNodePtr keyInfoNode, xmlSecKeyInfoCtxPtr keyInfoCtx) {
     }
     xmlSecKeyDestroy(key);
 
-    /* if we have keys manager, try it */
-    if(keyInfoCtx->keysMngr != NULL) {
+    /* if we have keys manager, try to find any key that matches the required key (if lax key search is allowed) */
+    if(((keyInfoCtx->flags & XMLSEC_KEYINFO_FLAGS_LAX_KEY_SEARCH) != 0) &&  (keyInfoCtx->keysMngr != NULL)) {
         key = xmlSecKeysMngrFindKey(keyInfoCtx->keysMngr, NULL, keyInfoCtx);
         if(key == NULL) {
             xmlSecInternalError("xmlSecKeysMngrFindKey", NULL);
@@ -1290,4 +1369,3 @@ xmlSecPtrListId
 xmlSecKeyPtrListGetKlass(void) {
     return(&xmlSecKeyPtrListKlass);
 }
-
